@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 from distutils import util
 import os
@@ -23,10 +21,10 @@ from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
@@ -43,12 +41,11 @@ from google.cloud.artifactregistry_v1beta2.types import service
 from google.cloud.artifactregistry_v1beta2.types import tag
 from google.cloud.artifactregistry_v1beta2.types import tag as gda_tag
 from google.cloud.artifactregistry_v1beta2.types import version
-from google.iam.v1 import iam_policy_pb2 as iam_policy  # type: ignore
-from google.iam.v1 import policy_pb2 as policy  # type: ignore
-from google.protobuf import empty_pb2 as empty  # type: ignore
-from google.protobuf import field_mask_pb2 as field_mask  # type: ignore
-from google.protobuf import timestamp_pb2 as timestamp  # type: ignore
-
+from google.iam.v1 import iam_policy_pb2  # type: ignore
+from google.iam.v1 import policy_pb2  # type: ignore
+from google.protobuf import empty_pb2  # type: ignore
+from google.protobuf import field_mask_pb2  # type: ignore
+from google.protobuf import timestamp_pb2  # type: ignore
 from .transports.base import ArtifactRegistryTransport, DEFAULT_CLIENT_INFO
 from .transports.grpc import ArtifactRegistryGrpcTransport
 from .transports.grpc_asyncio import ArtifactRegistryGrpcAsyncIOTransport
@@ -69,7 +66,7 @@ class ArtifactRegistryClientMeta(type):
     _transport_registry["grpc_asyncio"] = ArtifactRegistryGrpcAsyncIOTransport
 
     def get_transport_class(cls, label: str = None,) -> Type[ArtifactRegistryTransport]:
-        """Return an appropriate transport class.
+        """Returns an appropriate transport class.
 
         Args:
             label: The name of the desired transport. If none is
@@ -105,7 +102,8 @@ class ArtifactRegistryClient(metaclass=ArtifactRegistryClientMeta):
 
     @staticmethod
     def _get_default_mtls_endpoint(api_endpoint):
-        """Convert api endpoint to mTLS endpoint.
+        """Converts api endpoint to mTLS endpoint.
+
         Convert "*.sandbox.googleapis.com" and "*.googleapis.com" to
         "*.mtls.sandbox.googleapis.com" and "*.mtls.googleapis.com" respectively.
         Args:
@@ -139,7 +137,8 @@ class ArtifactRegistryClient(metaclass=ArtifactRegistryClientMeta):
 
     @classmethod
     def from_service_account_info(cls, info: dict, *args, **kwargs):
-        """Creates an instance of this client using the provided credentials info.
+        """Creates an instance of this client using the provided credentials
+            info.
 
         Args:
             info (dict): The service account private key info.
@@ -156,7 +155,7 @@ class ArtifactRegistryClient(metaclass=ArtifactRegistryClientMeta):
     @classmethod
     def from_service_account_file(cls, filename: str, *args, **kwargs):
         """Creates an instance of this client using the provided credentials
-        file.
+            file.
 
         Args:
             filename (str): The path to the service account private key json
@@ -175,23 +174,24 @@ class ArtifactRegistryClient(metaclass=ArtifactRegistryClientMeta):
 
     @property
     def transport(self) -> ArtifactRegistryTransport:
-        """Return the transport used by the client instance.
+        """Returns the transport used by the client instance.
 
         Returns:
-            ArtifactRegistryTransport: The transport used by the client instance.
+            ArtifactRegistryTransport: The transport used by the client
+                instance.
         """
         return self._transport
 
     @staticmethod
     def file_path(project: str, location: str, repo: str, file: str,) -> str:
-        """Return a fully-qualified file string."""
+        """Returns a fully-qualified file string."""
         return "projects/{project}/locations/{location}/repositories/{repo}/files/{file}".format(
             project=project, location=location, repo=repo, file=file,
         )
 
     @staticmethod
     def parse_file_path(path: str) -> Dict[str, str]:
-        """Parse a file path into its component segments."""
+        """Parses a file path into its component segments."""
         m = re.match(
             r"^projects/(?P<project>.+?)/locations/(?P<location>.+?)/repositories/(?P<repo>.+?)/files/(?P<file>.+?)$",
             path,
@@ -200,14 +200,14 @@ class ArtifactRegistryClient(metaclass=ArtifactRegistryClientMeta):
 
     @staticmethod
     def repository_path(project: str, location: str, repository: str,) -> str:
-        """Return a fully-qualified repository string."""
+        """Returns a fully-qualified repository string."""
         return "projects/{project}/locations/{location}/repositories/{repository}".format(
             project=project, location=location, repository=repository,
         )
 
     @staticmethod
     def parse_repository_path(path: str) -> Dict[str, str]:
-        """Parse a repository path into its component segments."""
+        """Parses a repository path into its component segments."""
         m = re.match(
             r"^projects/(?P<project>.+?)/locations/(?P<location>.+?)/repositories/(?P<repository>.+?)$",
             path,
@@ -216,7 +216,7 @@ class ArtifactRegistryClient(metaclass=ArtifactRegistryClientMeta):
 
     @staticmethod
     def common_billing_account_path(billing_account: str,) -> str:
-        """Return a fully-qualified billing_account string."""
+        """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
         )
@@ -229,7 +229,7 @@ class ArtifactRegistryClient(metaclass=ArtifactRegistryClientMeta):
 
     @staticmethod
     def common_folder_path(folder: str,) -> str:
-        """Return a fully-qualified folder string."""
+        """Returns a fully-qualified folder string."""
         return "folders/{folder}".format(folder=folder,)
 
     @staticmethod
@@ -240,7 +240,7 @@ class ArtifactRegistryClient(metaclass=ArtifactRegistryClientMeta):
 
     @staticmethod
     def common_organization_path(organization: str,) -> str:
-        """Return a fully-qualified organization string."""
+        """Returns a fully-qualified organization string."""
         return "organizations/{organization}".format(organization=organization,)
 
     @staticmethod
@@ -251,7 +251,7 @@ class ArtifactRegistryClient(metaclass=ArtifactRegistryClientMeta):
 
     @staticmethod
     def common_project_path(project: str,) -> str:
-        """Return a fully-qualified project string."""
+        """Returns a fully-qualified project string."""
         return "projects/{project}".format(project=project,)
 
     @staticmethod
@@ -262,7 +262,7 @@ class ArtifactRegistryClient(metaclass=ArtifactRegistryClientMeta):
 
     @staticmethod
     def common_location_path(project: str, location: str,) -> str:
-        """Return a fully-qualified location string."""
+        """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
             project=project, location=location,
         )
@@ -276,12 +276,12 @@ class ArtifactRegistryClient(metaclass=ArtifactRegistryClientMeta):
     def __init__(
         self,
         *,
-        credentials: Optional[credentials.Credentials] = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, ArtifactRegistryTransport, None] = None,
         client_options: Optional[client_options_lib.ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
-        """Instantiate the artifact registry client.
+        """Instantiates the artifact registry client.
 
         Args:
             credentials (Optional[google.auth.credentials.Credentials]): The
@@ -336,9 +336,10 @@ class ArtifactRegistryClient(metaclass=ArtifactRegistryClientMeta):
                 client_cert_source_func = client_options.client_cert_source
             else:
                 is_mtls = mtls.has_default_client_cert_source()
-                client_cert_source_func = (
-                    mtls.default_client_cert_source() if is_mtls else None
-                )
+                if is_mtls:
+                    client_cert_source_func = mtls.default_client_cert_source()
+                else:
+                    client_cert_source_func = None
 
         # Figure out which api endpoint to use.
         if client_options.api_endpoint is not None:
@@ -350,12 +351,14 @@ class ArtifactRegistryClient(metaclass=ArtifactRegistryClientMeta):
             elif use_mtls_env == "always":
                 api_endpoint = self.DEFAULT_MTLS_ENDPOINT
             elif use_mtls_env == "auto":
-                api_endpoint = (
-                    self.DEFAULT_MTLS_ENDPOINT if is_mtls else self.DEFAULT_ENDPOINT
-                )
+                if is_mtls:
+                    api_endpoint = self.DEFAULT_MTLS_ENDPOINT
+                else:
+                    api_endpoint = self.DEFAULT_ENDPOINT
             else:
                 raise MutualTLSChannelError(
-                    "Unsupported GOOGLE_API_USE_MTLS_ENDPOINT value. Accepted values: never, auto, always"
+                    "Unsupported GOOGLE_API_USE_MTLS_ENDPOINT value. Accepted "
+                    "values: never, auto, always"
                 )
 
         # Save or instantiate the transport.
@@ -370,8 +373,8 @@ class ArtifactRegistryClient(metaclass=ArtifactRegistryClientMeta):
                 )
             if client_options.scopes:
                 raise ValueError(
-                    "When providing a transport instance, "
-                    "provide its scopes directly."
+                    "When providing a transport instance, provide its scopes "
+                    "directly."
                 )
             self._transport = transport
         else:
@@ -407,7 +410,6 @@ class ArtifactRegistryClient(metaclass=ArtifactRegistryClientMeta):
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -439,10 +441,8 @@ class ArtifactRegistryClient(metaclass=ArtifactRegistryClientMeta):
         # there are no flattened fields.
         if not isinstance(request, repository.ListRepositoriesRequest):
             request = repository.ListRepositoriesRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if parent is not None:
                 request.parent = parent
 
@@ -490,7 +490,6 @@ class ArtifactRegistryClient(metaclass=ArtifactRegistryClientMeta):
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -519,10 +518,8 @@ class ArtifactRegistryClient(metaclass=ArtifactRegistryClientMeta):
         # there are no flattened fields.
         if not isinstance(request, repository.GetRepositoryRequest):
             request = repository.GetRepositoryRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if name is not None:
                 request.name = name
 
@@ -580,7 +577,6 @@ class ArtifactRegistryClient(metaclass=ArtifactRegistryClientMeta):
                 This corresponds to the ``repository_id`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -613,10 +609,8 @@ class ArtifactRegistryClient(metaclass=ArtifactRegistryClientMeta):
         # there are no flattened fields.
         if not isinstance(request, gda_repository.CreateRepositoryRequest):
             request = gda_repository.CreateRepositoryRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if parent is not None:
                 request.parent = parent
             if repository is not None:
@@ -653,7 +647,7 @@ class ArtifactRegistryClient(metaclass=ArtifactRegistryClientMeta):
         request: gda_repository.UpdateRepositoryRequest = None,
         *,
         repository: gda_repository.Repository = None,
-        update_mask: field_mask.FieldMask = None,
+        update_mask: field_mask_pb2.FieldMask = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
@@ -678,7 +672,6 @@ class ArtifactRegistryClient(metaclass=ArtifactRegistryClientMeta):
                 This corresponds to the ``update_mask`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -707,10 +700,8 @@ class ArtifactRegistryClient(metaclass=ArtifactRegistryClientMeta):
         # there are no flattened fields.
         if not isinstance(request, gda_repository.UpdateRepositoryRequest):
             request = gda_repository.UpdateRepositoryRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if repository is not None:
                 request.repository = repository
             if update_mask is not None:
@@ -756,7 +747,6 @@ class ArtifactRegistryClient(metaclass=ArtifactRegistryClientMeta):
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -798,10 +788,8 @@ class ArtifactRegistryClient(metaclass=ArtifactRegistryClientMeta):
         # there are no flattened fields.
         if not isinstance(request, repository.DeleteRepositoryRequest):
             request = repository.DeleteRepositoryRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if name is not None:
                 request.name = name
 
@@ -822,7 +810,7 @@ class ArtifactRegistryClient(metaclass=ArtifactRegistryClientMeta):
         response = operation.from_gapic(
             response,
             self._transport.operations_client,
-            empty.Empty,
+            empty_pb2.Empty,
             metadata_type=service.OperationMetadata,
         )
 
@@ -850,7 +838,6 @@ class ArtifactRegistryClient(metaclass=ArtifactRegistryClientMeta):
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -881,10 +868,8 @@ class ArtifactRegistryClient(metaclass=ArtifactRegistryClientMeta):
         # there are no flattened fields.
         if not isinstance(request, package.ListPackagesRequest):
             request = package.ListPackagesRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if parent is not None:
                 request.parent = parent
 
@@ -929,7 +914,6 @@ class ArtifactRegistryClient(metaclass=ArtifactRegistryClientMeta):
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -958,10 +942,8 @@ class ArtifactRegistryClient(metaclass=ArtifactRegistryClientMeta):
         # there are no flattened fields.
         if not isinstance(request, package.GetPackageRequest):
             request = package.GetPackageRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if name is not None:
                 request.name = name
 
@@ -1002,7 +984,6 @@ class ArtifactRegistryClient(metaclass=ArtifactRegistryClientMeta):
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1044,10 +1025,8 @@ class ArtifactRegistryClient(metaclass=ArtifactRegistryClientMeta):
         # there are no flattened fields.
         if not isinstance(request, package.DeletePackageRequest):
             request = package.DeletePackageRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if name is not None:
                 request.name = name
 
@@ -1068,7 +1047,7 @@ class ArtifactRegistryClient(metaclass=ArtifactRegistryClientMeta):
         response = operation.from_gapic(
             response,
             self._transport.operations_client,
-            empty.Empty,
+            empty_pb2.Empty,
             metadata_type=service.OperationMetadata,
         )
 
@@ -1096,7 +1075,6 @@ class ArtifactRegistryClient(metaclass=ArtifactRegistryClientMeta):
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1127,10 +1105,8 @@ class ArtifactRegistryClient(metaclass=ArtifactRegistryClientMeta):
         # there are no flattened fields.
         if not isinstance(request, version.ListVersionsRequest):
             request = version.ListVersionsRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if parent is not None:
                 request.parent = parent
 
@@ -1175,7 +1151,6 @@ class ArtifactRegistryClient(metaclass=ArtifactRegistryClientMeta):
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1207,10 +1182,8 @@ class ArtifactRegistryClient(metaclass=ArtifactRegistryClientMeta):
         # there are no flattened fields.
         if not isinstance(request, version.GetVersionRequest):
             request = version.GetVersionRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if name is not None:
                 request.name = name
 
@@ -1251,7 +1224,6 @@ class ArtifactRegistryClient(metaclass=ArtifactRegistryClientMeta):
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1293,10 +1265,8 @@ class ArtifactRegistryClient(metaclass=ArtifactRegistryClientMeta):
         # there are no flattened fields.
         if not isinstance(request, version.DeleteVersionRequest):
             request = version.DeleteVersionRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if name is not None:
                 request.name = name
 
@@ -1317,7 +1287,7 @@ class ArtifactRegistryClient(metaclass=ArtifactRegistryClientMeta):
         response = operation.from_gapic(
             response,
             self._transport.operations_client,
-            empty.Empty,
+            empty_pb2.Empty,
             metadata_type=service.OperationMetadata,
         )
 
@@ -1345,7 +1315,6 @@ class ArtifactRegistryClient(metaclass=ArtifactRegistryClientMeta):
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1376,10 +1345,8 @@ class ArtifactRegistryClient(metaclass=ArtifactRegistryClientMeta):
         # there are no flattened fields.
         if not isinstance(request, file.ListFilesRequest):
             request = file.ListFilesRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if parent is not None:
                 request.parent = parent
 
@@ -1424,7 +1391,6 @@ class ArtifactRegistryClient(metaclass=ArtifactRegistryClientMeta):
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1454,10 +1420,8 @@ class ArtifactRegistryClient(metaclass=ArtifactRegistryClientMeta):
         # there are no flattened fields.
         if not isinstance(request, file.GetFileRequest):
             request = file.GetFileRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if name is not None:
                 request.name = name
 
@@ -1498,7 +1462,6 @@ class ArtifactRegistryClient(metaclass=ArtifactRegistryClientMeta):
                 This corresponds to the ``parent`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1529,10 +1492,8 @@ class ArtifactRegistryClient(metaclass=ArtifactRegistryClientMeta):
         # there are no flattened fields.
         if not isinstance(request, tag.ListTagsRequest):
             request = tag.ListTagsRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if parent is not None:
                 request.parent = parent
 
@@ -1577,7 +1538,6 @@ class ArtifactRegistryClient(metaclass=ArtifactRegistryClientMeta):
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1607,10 +1567,8 @@ class ArtifactRegistryClient(metaclass=ArtifactRegistryClientMeta):
         # there are no flattened fields.
         if not isinstance(request, tag.GetTagRequest):
             request = tag.GetTagRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if name is not None:
                 request.name = name
 
@@ -1665,7 +1623,6 @@ class ArtifactRegistryClient(metaclass=ArtifactRegistryClientMeta):
                 This corresponds to the ``tag_id`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1695,10 +1652,8 @@ class ArtifactRegistryClient(metaclass=ArtifactRegistryClientMeta):
         # there are no flattened fields.
         if not isinstance(request, gda_tag.CreateTagRequest):
             request = gda_tag.CreateTagRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if parent is not None:
                 request.parent = parent
             if tag is not None:
@@ -1727,7 +1682,7 @@ class ArtifactRegistryClient(metaclass=ArtifactRegistryClientMeta):
         request: gda_tag.UpdateTagRequest = None,
         *,
         tag: gda_tag.Tag = None,
-        update_mask: field_mask.FieldMask = None,
+        update_mask: field_mask_pb2.FieldMask = None,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
@@ -1753,7 +1708,6 @@ class ArtifactRegistryClient(metaclass=ArtifactRegistryClientMeta):
                 This corresponds to the ``update_mask`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1783,10 +1737,8 @@ class ArtifactRegistryClient(metaclass=ArtifactRegistryClientMeta):
         # there are no flattened fields.
         if not isinstance(request, gda_tag.UpdateTagRequest):
             request = gda_tag.UpdateTagRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if tag is not None:
                 request.tag = tag
             if update_mask is not None:
@@ -1827,7 +1779,6 @@ class ArtifactRegistryClient(metaclass=ArtifactRegistryClientMeta):
                 This corresponds to the ``name`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1850,10 +1801,8 @@ class ArtifactRegistryClient(metaclass=ArtifactRegistryClientMeta):
         # there are no flattened fields.
         if not isinstance(request, tag.DeleteTagRequest):
             request = tag.DeleteTagRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if name is not None:
                 request.name = name
 
@@ -1874,19 +1823,18 @@ class ArtifactRegistryClient(metaclass=ArtifactRegistryClientMeta):
 
     def set_iam_policy(
         self,
-        request: iam_policy.SetIamPolicyRequest = None,
+        request: iam_policy_pb2.SetIamPolicyRequest = None,
         *,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
-    ) -> policy.Policy:
+    ) -> policy_pb2.Policy:
         r"""Updates the IAM policy for a given resource.
 
         Args:
             request (google.iam.v1.iam_policy_pb2.SetIamPolicyRequest):
                 The request object. Request message for `SetIamPolicy`
                 method.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1953,14 +1901,13 @@ class ArtifactRegistryClient(metaclass=ArtifactRegistryClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-
         if isinstance(request, dict):
             # The request isn't a proto-plus wrapped type,
             # so it must be constructed via keyword expansion.
-            request = iam_policy.SetIamPolicyRequest(**request)
+            request = iam_policy_pb2.SetIamPolicyRequest(**request)
         elif not request:
             # Null request, just make one.
-            request = iam_policy.SetIamPolicyRequest()
+            request = iam_policy_pb2.SetIamPolicyRequest()
 
         # Wrap the RPC method; this adds retry and timeout information,
         # and friendly error handling.
@@ -1980,19 +1927,18 @@ class ArtifactRegistryClient(metaclass=ArtifactRegistryClientMeta):
 
     def get_iam_policy(
         self,
-        request: iam_policy.GetIamPolicyRequest = None,
+        request: iam_policy_pb2.GetIamPolicyRequest = None,
         *,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
-    ) -> policy.Policy:
+    ) -> policy_pb2.Policy:
         r"""Gets the IAM policy for a given resource.
 
         Args:
             request (google.iam.v1.iam_policy_pb2.GetIamPolicyRequest):
                 The request object. Request message for `GetIamPolicy`
                 method.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -2059,14 +2005,13 @@ class ArtifactRegistryClient(metaclass=ArtifactRegistryClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-
         if isinstance(request, dict):
             # The request isn't a proto-plus wrapped type,
             # so it must be constructed via keyword expansion.
-            request = iam_policy.GetIamPolicyRequest(**request)
+            request = iam_policy_pb2.GetIamPolicyRequest(**request)
         elif not request:
             # Null request, just make one.
-            request = iam_policy.GetIamPolicyRequest()
+            request = iam_policy_pb2.GetIamPolicyRequest()
 
         # Wrap the RPC method; this adds retry and timeout information,
         # and friendly error handling.
@@ -2086,12 +2031,12 @@ class ArtifactRegistryClient(metaclass=ArtifactRegistryClientMeta):
 
     def test_iam_permissions(
         self,
-        request: iam_policy.TestIamPermissionsRequest = None,
+        request: iam_policy_pb2.TestIamPermissionsRequest = None,
         *,
         retry: retries.Retry = gapic_v1.method.DEFAULT,
         timeout: float = None,
         metadata: Sequence[Tuple[str, str]] = (),
-    ) -> iam_policy.TestIamPermissionsResponse:
+    ) -> iam_policy_pb2.TestIamPermissionsResponse:
         r"""Tests if the caller has a list of permissions on a
         resource.
 
@@ -2099,7 +2044,6 @@ class ArtifactRegistryClient(metaclass=ArtifactRegistryClientMeta):
             request (google.iam.v1.iam_policy_pb2.TestIamPermissionsRequest):
                 The request object. Request message for
                 `TestIamPermissions` method.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -2111,14 +2055,13 @@ class ArtifactRegistryClient(metaclass=ArtifactRegistryClientMeta):
                 Response message for TestIamPermissions method.
         """
         # Create or coerce a protobuf request object.
-
         if isinstance(request, dict):
             # The request isn't a proto-plus wrapped type,
             # so it must be constructed via keyword expansion.
-            request = iam_policy.TestIamPermissionsRequest(**request)
+            request = iam_policy_pb2.TestIamPermissionsRequest(**request)
         elif not request:
             # Null request, just make one.
-            request = iam_policy.TestIamPermissionsRequest()
+            request = iam_policy_pb2.TestIamPermissionsRequest()
 
         # Wrap the RPC method; this adds retry and timeout information,
         # and friendly error handling.
